import React, { useState } from 'react';
import ReactDOM from 'react-dom';
import { useNJMap } from './useNJMap';
import { useData } from './useData';
import { BubbleMap } from './BubbleMap/index.js';
import { DateHistogram } from './DateHistogram/index.js';

const width = 960;
const height = 500;
const dateHistogramSize = 0.2;

const xValue = d => d['Annual_Salary'];

const App = () => {
  const NJMap = useNJMap();
  const data = useData();
  const [brushExtent, setBrushExtent] = useState();

  if (!NJMap || !data) {
    return <pre>Loading...</pre>;
  }

  const filteredData = brushExtent
    ? data.filter(d => {
        const date = xValue(d);
        return date > brushExtent[0] && date < brushExtent[1];
      })
    : data;

  return (
    <svg width={width} height={height}>
      <BubbleMap
        data={data}
        filteredData={filteredData}
        NJMap={NJMap}
      />
      
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
